@@ -30,9 +30,10 @@ CredentialAutocomplete.prototype.itemClick = async function(e, input, uuid) {
     input.focus();
 };
 
-CredentialAutocomplete.prototype.itemEnter = async function(index, elements) {
-    const usernameValue = elements[index].value;
-    this.fillPassword(usernameValue, index, elements[index].uuid);
+CredentialAutocomplete.prototype.itemEnter = async function(index, item) {
+    const usernameValue = item?.getElementsByTagName('input')[0].value;
+    const uuid = item?.getAttribute('uuid');
+    this.fillPassword(usernameValue, index, uuid);
 };
 
 CredentialAutocomplete.prototype.fillPassword = async function(value, index, uuid) {
