@@ -26,7 +26,7 @@
             }
 
             const id = e.target.id;
-            browser.tabs.sendMessage(tab.id, {
+            browser.tabs.sendMessage(tab?.id, {
                 action: 'fill_user_pass_with_specific_login',
                 id: Number(id),
                 uuid: uuid
@@ -39,7 +39,7 @@
     }
 
     if (logins.length > 1) {
-        document.getElementById('filter-block').style = '';
+        $('#filter-block').show();
         const filter = document.getElementById('login-filter');
         filter.addEventListener('keyup', (e) => {
             if (!e.isTrusted) {
